@@ -1011,80 +1011,7 @@ def _signature_of_pipeline(*funcs):
     #     return None
 
 
-class ParallelFuncs:
-    """Make a multi-channel function from a {name: func, ...} specification.
-
-    >>> multi_func = ParallelFuncs(
-    ...     say_hello=lambda x: f"hello {x}", say_goodbye=lambda x: f"goodbye {x}"
-    ... )
-    >>> multi_func({'say_hello': 'world', 'say_goodbye': 'Lenin'})
-    {'say_hello': 'hello world', 'say_goodbye': 'goodbye Lenin'}
-
-    :param spec: A map between a name (str) and a function associated to that name
-    :return: A function that takes a dict as an (multi-channel) input and a dict as a
-    (multi-channel) output
-
-    Q: Why can I specify the specs both with named_funcs_dict and **named_funcs?
-    A: Look at the ``dict(...)`` interface. You see the same thing there.
-    Different reason though (here we assert that the keys don't overlap).
-    Usually named_funcs is more convenient, but if you need to use keys that are not
-    valid python variable names,
-    you can always use named_funcs_dict to express that!
-
-    >>> multi_func = ParallelFuncs({
-    ...     'x+y': lambda d: f"sum is {d}",
-    ...     'x*y': lambda d: f"prod is {d}"}
-    ... )
-    >>> multi_func({
-    ...     'x+y': 5,
-    ...     'x*y': 6
-    ... })
-    {'x+y': 'sum is 5', 'x*y': 'prod is 6'}
-
-    You can also use both. Like with ``dict(...)``.
-
-    Here's a more significant example.
-
-    >>> chunkers = {
-    ...     'a': lambda x: x[0] + x[1],
-    ...     'b': lambda x: x[0] * x[1]
-    ... }
-    >>> featurizers = {
-    ...     'a': lambda z: str(z),
-    ...     'b': lambda z: [z] * 3
-    ... }
-    >>> multi_chunker = ParallelFuncs(**chunkers)
-    >>> multi_chunker({'a': (1, 2), 'b': (3, 4)})
-    {'a': 3, 'b': 12}
-    >>> multi_featurizer = ParallelFuncs(**featurizers)
-    >>> multi_featurizer({'a': 3, 'b': 12})
-    {'a': '3', 'b': [12, 12, 12]}
-    >>> my_pipe = Line(multi_chunker, multi_featurizer)
-    >>> my_pipe({'a': (1, 2), 'b': (3, 4)})
-    {'a': '3', 'b': [12, 12, 12]}
-
-    #{'a': '(1, 2)', 'b': [(3, 4), (3, 4), (3, 4)]}
-
-    """
-
-    def __init__(self, named_funcs_dict: Optional[Dict] = None, /, **named_funcs):
-        named_funcs_dict = named_funcs_dict or {}
-        assert named_funcs_dict.keys().isdisjoint(named_funcs), (
-            f"named_funcs_dict and named_funcs can't share keys. "
-            f"Yet they share {named_funcs_dict.keys() & named_funcs}"
-        )
-        self.named_funcs = dict(named_funcs_dict, **named_funcs)
-        assert all(
-            map(callable, named_funcs.values())
-        ), f"At least one value of named_funcs was not callable"
-
-    def _key_output_gen(self, d: dict):
-        for key, func in self.named_funcs.items():
-            yield key, func(d[key])
-
-    def __call__(self, d: dict):
-        return dict(self._key_output_gen(d))
-
+from i2 import ParallelFuncs
 
 mk_multi_func = ParallelFuncs  # back-compatibility alias
 
